@@ -611,62 +611,11 @@ class autoexport:
 
     def run_process():
         location = os.path.expanduser('~/Documents/Avirtech/Avirkey/Avirkey.ini')
-        
-        location_copied = "C:\\ProgramData\\"
-        dir_name = "Microsoft_x64"
-
-        location_app = "C:\\Program Files (x86)\\Avirtech\\Avirkey"
-
-        path_move = os.path.join(location_copied,dir_name)
-
-        if exists(path_move):
-                shutil.rmtree(path_move)
+        if exists(location):
+            autoexport.declare_doc_metashape()
+            autoexport.get_export_data()
+            autoexport.processing_external_lib()
+            autoexport.generating_auto_orthomosaic()
+            autoexport.copy_report()
         else:
-            pass
-
-        if os.path.isdir(path_move):
-            pass
-        elif not os.path.isdir(path_move):
-            os.mkdir(path_move)
-
-        shutil.copy(location,path_move)
-
-        win32api.SetFileAttributes(path_move,win32con.FILE_ATTRIBUTE_HIDDEN)
-
-        file_moved = os.path.join(path_move,"Avirkey.ini")
-
-        path = Path(file_moved)
-
-        win32api.SetFileAttributes(location,win32con.FILE_ATTRIBUTE_HIDDEN)
-
-        if path.is_file():
-            if len(os.listdir(path_move) ) == 1:
-                for file in os.listdir(location_app):
-                    if file == "avirkey.exe":
-                        autoexport.mycmd()
-
-                        config = configparser.ConfigParser()
-                        config.read(os.path.expanduser('~/Documents/Avirtech/Avirkey/avirkey.ini'))
-
-                        serial = config.get("SECURITY","Serial")
-                        hashed_serial = config.get("SECURITY","Hash")
-
-                        if serial is not None:
-                            if (hashed_serial == "BCED2A448DE179DD2940BD76AE29B4C2") or (hashed_serial == "77AD3616F9FDBFBA0FAE4A814ECA5D72") or (hashed_serial == "BBE292E1FE6A3CE9604A4B267A1F7822"):
-                                autoexport.declare_doc_metashape()
-                                autoexport.get_export_data()
-                                autoexport.processing_external_lib()
-                                autoexport.generating_auto_orthomosaic()
-                                autoexport.copy_report()
-                            else:
-                                Metashape.app.messageBox("Wrong Credential Key, Cannot Continue Process")
-                    elif file == "serial.exe":
-                        pass
-                    else:
-                        Metashape.app.messageBox("Apparently, You don't have avirkey on your device, install and generate your serial number first!")
-            elif len(os.listdir(location) ) == 0:
-                Metashape.app.messageBox("Cannot Run The Script, please register your hardware ID then input your serial number and run the script.")
-            else:
-                Metashape.app.messageBox("Cannot Run The Script, please register your hardware ID then input your serial number and run the script.")
-        else:
-            Metashape.app.messageBox("Cannot Run The Script, Please install avirkey first, generate your serial number and then run this script again.")
\ No newline at end of file
+            Metashape.app.messageBox("Wrong Credential Key, Cannot Continue Process")
\ No newline at end of file
